@@ -1,6 +1,6 @@
 library(buildmer)
 library(testthat)
-test_that('buildglmmTBB',{
+test_that('buildglmmTMB',{
 	skip_on_cran()
 	model <- buildglmmTMB(Reaction ~ Days + (Days|Subject),data=lme4::sleepstudy)
 	buildmer:::testthat.compare.df(model@p$results,'buildglmmTMB')
